package com.jiuqi.util;

import java.text.DecimalFormat;

/* loaded from: com_jiuqi_util.jar:com/jiuqi/util/DataUtil.class */
public class DataUtil {
    public static final String DATA_NULL_VALUE = "--";
    public static final int PERCENT_DECIMAL = 1;

    public static int compare(Object o1, Object o2) {
        if (o1 == null && o2 == null) {
            return 0;
        }
        if (o1 == null) {
            return -1;
        }
        if (o2 == null) {
            return 1;
        }
        double d1 = ((Double) o1).doubleValue();
        double d2 = ((Double) o2).doubleValue();
        if (d1 < d2) {
            return -1;
        }
        return d1 > d2 ? 1 : 0;
    }

    public static String getDigitValue(int demical, double src) {
        DecimalFormat df = new DecimalFormat();
        StringBuffer buff = new StringBuffer();
        buff.append("#");
        if (demical > -1) {
            if (demical > 0) {
                buff.append("0.");
            } else {
                buff.append("#");
            }
            for (int i = 0; i < demical; i++) {
                buff.append(JqLib.SQL_FALSE);
            }
        } else {
            buff.append("#.#####");
        }
        df.applyPattern(buff.toString());
        return df.format(src);
    }

    public static boolean isDataValue(Object value) {
        if (value == null) {
            return false;
        }
        return (value instanceof Double) || (value instanceof Integer) || (value instanceof Float) || (value instanceof Long) || (value instanceof Short);
    }

    public static Double divide(Object o1, Object o2) {
        if (o1 == null) {
            return new Double(0.0d);
        }
        if (o2 != null && isDataValue(o1)) {
            double v1 = ((Double) o1).doubleValue();
            double v2 = ((Double) o2).doubleValue();
            if (v2 == 0.0d) {
                return null;
            }
            return new Double(v1 / v2);
        }
        return null;
    }

    public static Object calcSum(Object[] values) {
        if (values == null || values.length == 0) {
            return null;
        }
        Object validObj = null;
        int i = 0;
        while (true) {
            if (i >= values.length) {
                break;
            }
            if (values[i] == null) {
                i++;
            } else {
                validObj = values[i];
                break;
            }
        }
        if (validObj == null) {
            return null;
        }
        if (validObj instanceof Double) {
            double returnValue = 0.0d;
            for (int i2 = 0; i2 < values.length; i2++) {
                if (values[i2] != null) {
                    returnValue += ((Double) values[i2]).doubleValue();
                }
            }
            return new Double(returnValue);
        }
        if ((validObj instanceof Integer) || (validObj instanceof Long) || (validObj instanceof Short)) {
            long returnValue2 = 0;
            for (int i3 = 0; i3 < values.length; i3++) {
                if (values[i3] != null) {
                    returnValue2 += ((Integer) values[i3]).intValue();
                }
            }
            return new Long(returnValue2);
        }
        if (validObj instanceof Float) {
            float returnValue3 = 0.0f;
            for (int i4 = 0; i4 < values.length; i4++) {
                if (values[i4] != null) {
                    returnValue3 += ((Float) values[i4]).floatValue();
                }
            }
            return new Float(returnValue3);
        }
        return "";
    }

    public static int[] calcPlace(Object[] values) {
        if (values == null) {
            return null;
        }
        if (values.length == 0) {
            return new int[0];
        }
        int[] returnPlace = new int[values.length];
        for (int i = 0; i < values.length; i++) {
            int p = 1;
            for (int j = 0; j < values.length; j++) {
                if (j != i && compare(values[j], values[i]) > 0) {
                    p++;
                }
            }
            returnPlace[i] = p;
        }
        return returnPlace;
    }

    public static boolean isLessthanOrEqualZeroData(Object value) {
        if (isNegativeData(value) || !isDataValue(value)) {
            return true;
        }
        double d = ((Double) value).doubleValue();
        return d == 0.0d;
    }

    public static boolean isNegativeData(Object value) {
        if (!isDataValue(value)) {
            return true;
        }
        double d = ((Double) value).doubleValue();
        return d < 0.0d;
    }

    public static boolean isZeroData(Object value) {
        if (!isDataValue(value)) {
            return false;
        }
        double d = ((Double) value).doubleValue();
        return d == 0.0d;
    }

    public static String[] calcPercent(Object[] values) {
        if (values == null) {
            return null;
        }
        if (values.length == 0) {
            return new String[0];
        }
        String[] returnPercent = new String[values.length];
        for (Object obj : values) {
            if (isNegativeData(obj)) {
                for (int j = 0; j < values.length; j++) {
                    returnPercent[j] = DATA_NULL_VALUE;
                }
                return returnPercent;
            }
        }
        Object sumValue = calcSum(values);
        if (sumValue != null) {
            if (isLessthanOrEqualZeroData(sumValue)) {
                for (int i = 0; i < values.length; i++) {
                    returnPercent[i] = DATA_NULL_VALUE;
                }
                return returnPercent;
            }
            int specialPercentIndex = -1;
            double otherPercentValue = 0.0d;
            boolean notSpecialDealed = true;
            for (int i2 = 0; i2 < values.length; i2++) {
                Object value = values[i2];
                if (value == null) {
                    returnPercent[i2] = DATA_NULL_VALUE;
                } else if (!isZeroData(value) && notSpecialDealed) {
                    specialPercentIndex = i2;
                    notSpecialDealed = false;
                } else {
                    try {
                        double percent = 100.0d * divide(value, sumValue).doubleValue();
                        String percentStr = getDigitValue(1, percent);
                        returnPercent[i2] = String.valueOf(percentStr) + "%";
                        try {
                            otherPercentValue += Double.parseDouble(percentStr);
                        } catch (NumberFormatException unused) {
                        }
                    } catch (Exception unused2) {
                    }
                }
            }
            if (specialPercentIndex >= 0) {
                returnPercent[specialPercentIndex] = String.valueOf(getDigitValue(1, 100.0d - otherPercentValue)) + "%";
            }
        }
        return returnPercent;
    }
}
